/* --- app.js ----- */

define(['jquery', 'config'], function($, config) {

	var config = config.app;
	var trans = config.defStrings ? $.extend(true, {}, config.defStrings) : {};

	/*
	 * === APP INTERFACE =====
	 */

	var app = {
		config:         config,
		connection:     null,
		init:           appInit,
		language:       null,
		localStorage:   null,
		//myOrganization: myOrg,
		navigation:     null,
		notification:   null,
		onDeviceReady:  onDeviceReady,
		trans:          trans
	};

	/*
	 * === FEATURE DETECTION =====
	 */

	var reqFeatures = {};

	// --- localStorage ----- //
	app.localStorage = (function() {
		var uid = new Date;
		var storage;
		var result;

		try {
			(storage = window.localStorage).setItem(uid, uid);
			result = storage.getItem(uid) == uid;
			storage.removeItem(uid);
			return result && storage;
		} catch(e) {}
	}());

	reqFeatures.localStorage = app.localStorage;
	// --- /locatStorage ----- //


	// --- otherFeatures/ ----- //


	// Abort if not all required features are detected
	for (var feat in reqFeatures) {
		if (reqFeatures.hasOwnProperty(feat) && !reqFeatures[feat]) {
			$(document.documentElement).removeClass('js-init js-on');
			return;
		}
	}


	/*
	 * === MODULES =====
	 */

		require(['modules/language', 'modules/connection', 'modules/notification', 'modules/navigation'], function(lang, connection, notification, navigation) {

			app.language =     lang.init(config.languages);
			app.connection =   connection;
			app.notification = notification;
			app.navigation =   navigation;

			$(document).triggerHandler('onlanguageready', [app]);
			$(document).triggerHandler('onconnectionready', [app]);
			$(document).triggerHandler('onnotificationready', [app]);
			$(document).triggerHandler('onnavigationready', [app]);
			$(document).triggerHandler('app.extend', [app]);

			app.init();

			// --- language ----- //
			var language = app.language;

			// Set language if not set yet
			if (!language.isSet()) {
				language.setPreferred();
			}

		});
	//});

	// Show app instead of 'browser does not support' message
	$(document.documentElement).removeClass('js-init');


	/*
	 * === DEVICE =====
	 */

	var deviceReady = false;
	var initialized = false;
	
	function onDeviceReady() {
		deviceReady = true;
		app.init();
	}
	$(document).one('deviceready', app.onDeviceReady);

	function appInit() {
		if (initialized) {
			return;
		}
		
		var connection = app.connection;
		var navigation = app.navigation;

		if (deviceReady && connection && navigation) {
			if (connection.check()) {
				initialized = true;
				$.mobile.changePage('http://'+navigation.getDomain()+'/app/'+navigation.getHomePageAlias());
				//navigation.gotoUrl('http://'+navigation.getDomain()+'/app/'+navigation.getHomePageAlias());
			} else {
				connection.alertDisconnected();
			}
		}
	}


	/*
	 * === MY ORGANIZATION =====
	 */

	var myOrg = {
		initForm:    initMyOrganizationForm,
		initContact: initContactLink,
		get:         getMyOrganization,
		set:         setMyOrganization
	};

	function initMyOrganizationForm() {
		var $form = $('.set-my-organization');
		var $select;
		var $emptyOption;
		var emptyOptionResetLabel = '&mdash; selectie ongedaan maken &mdash;';
		var $submit;
		var orgId;

		/*function removeEmptyOption() {
			if ($emptyOption && !$emptyOption.prop('selected')) {
				$emptyOption.remove();
				$emptyOption = null;
			}
		}*/

		if ($form.length) {
			$select = $('select', $form);
			$emptyOption = $('[value=""]', $select);
			$submit = $('[type="submit"]', $form);
			orgId = myOrg.get();

			if (orgId) {
				$select
					.val(orgId)
					.selectmenu('refresh', true);
				//removeEmptyOption();
				$emptyOption.html(emptyOptionResetLabel);
			}

			/*$select.on('change', function() {
				//$form.triggerHandler('submit');
				removeEmptyOption();
			});*/

			$form
				//.addClass('js-auto-submit')
				.on('submit', function(e) {
					e.preventDefault();
					myOrg.set($select.val());
					//removeEmptyOption();
				});
		}

	};

	function getMyOrganization() {
		return app.localStorage.getItem('my-org');
	};

	function setMyOrganization(orgId) {
		app.localStorage.setItem('my-org', orgId);
		myOrg.initContact(orgId);
	};

	function initContactLink(orgId) {
		var $contact = $('.footer .app-contact a, a.app-mijn-zorginstelling');
		var hrefArr = ($contact.attr('href') || '').split('?');

		if ($contact.length) {
			orgId = orgId || myOrg.get();

			if (orgId) {
				hrefArr[0] += '/' + orgId;
				$contact.attr('href', hrefArr.join('?'));
			}
		}
	}

	// Initialize my organization
	$(document).on('pageshow', function() {
		myOrg.initForm();
		myOrg.initContact();
	});

	// Return app interface
	return app;
});