/* --- main.js ----- */

var app = (function($){
	/*
	 * Declare some 'object properties'
	 * 
	 */
	var localStorage	= window.localStorage;
	var homepageAlias	= 'nl-home';
    var domain			= 'http://goma-app.centramed.nl';
    //var domain			= 'http://sandera.goma.dev5.intern.prezent.nl/';

	/**
	 * setDomain
	 *
	 * For use in local.js to override the domain
	 * @param	{String}	domainStr	New domain
	 */ 
	function setDomain(domainStr) {
		domain = domainStr;
	}
	
	/* ====================================================== */
	
	
	/*
	 * Locale storage functions
	 * 
	 */

	function getLocalStorageItem(key) {
		return localStorage.getItem(key);
	}
	
	function setLocalStorageItem(key,value) {
		return localStorage.setItem(key,value);
	}
	
	function getLocationAlias() {
		return 'nl-home';
	}
	
	/* ====================================================== */
	
	/*
	 * My organization
	 * 
	 */

	var myOrg = {
		initForm:    initMyOrganizationForm,
		initContact: initContactLink,
		get:         getMyOrganization,
		set:         setMyOrganization
	};

	function initMyOrganizationForm() {
		var $form = $('.set-my-organization');
		var $select;
		var $emptyOption;
		var emptyOptionResetLabel = '&mdash; selectie ongedaan maken &mdash;';
		var $submit;
		var orgId;

		/*function removeEmptyOption() {
			if ($emptyOption && !$emptyOption.prop('selected')) {
				$emptyOption.remove();
				$emptyOption = null;
			}
		}*/

		if ($form.length) {
			$select = $('select', $form);
			$emptyOption = $('[value=""]', $select);
			$submit = $('[type="submit"]', $form);
			orgId = myOrg.get();

			if (orgId) {
				$select
					.val(orgId)
					.selectmenu('refresh', true);
				//removeEmptyOption();
				$emptyOption.html(emptyOptionResetLabel);
			}

			/*$select.on('change', function() {
				//$form.triggerHandler('submit');
				removeEmptyOption();
			});*/

			$form
				//.addClass('js-auto-submit')
				.on('submit', function(e) {
					e.preventDefault();
					myOrg.set($select.val());
					//removeEmptyOption();
				});
		}

	};

	function getMyOrganization() {
		return getLocalStorageItem('my-org');
	};

	function setMyOrganization(orgId) {
		setLocalStorageItem('my-org', orgId);
		myOrg.initContact(orgId);
	};

	function initContactLink(orgId) {
		var $contact = $('.footer .app-contact a, a.app-mijn-zorginstelling');
		var hrefArr = ($contact.attr('href') || '').split('?');

		if ($contact.length) {
			orgId = orgId || myOrg.get();

			if (orgId) {
				hrefArr[0] += '/' + orgId;
				$contact.attr('href', hrefArr.join('?'));
			}
		}
	}

	// Initialize my organization
	/*$(document).on('pageshow', function() {
		myOrg.initForm();
		myOrg.initContact();
	});*/
	
	/* ====================================================== */
	
	
	/*
	 * Network connection functions
	 * 
	 */
	
	function checkConnection() {
		//Just to ensure that we can work in an webenvironment
		if (!navigator.network) {
			return true;
		}
		
        var networkState = navigator.network.connection.type;

        var states = {};
        states[Connection.UNKNOWN]  = 'Unknown connection';
        states[Connection.ETHERNET] = 'Ethernet connection';
        states[Connection.WIFI]     = 'WiFi connection';
        states[Connection.CELL_2G]  = 'Cell 2G connection';
        states[Connection.CELL_3G]  = 'Cell 3G connection';
        states[Connection.CELL_4G]  = 'Cell 4G connection';
        states[Connection.NONE]     = null;

        return states[networkState];
    }
	
	function onOnline() {
	}
	
	function onOffline() {
		alert(noInternetConnectionText());
	}
	
	function noInternetConnectionText() {
		return "Er is momenteel geen internet verbinding mogelijk.\nSommige onderdelen van deze app kunnen mogelijk niet goed of helemaal niet functioneren";
	}
	
	/* ====================================================== */
	
	
	/*
	 * Device ready
	 * 
	 */
	
	function onDeviceReady() {
        if (window.StatusBar) {
            StatusBar.styleLightContent();
        }
        if (window.device && device.platform.toUpperCase() === 'IOS') {
            $(document.documentElement).addClass('platform-ios');
        }
		document.addEventListener('online', onOnline, false);
		document.addEventListener('offline', onOffline, false);
		
		if (!checkConnection()) {
			alert(noInternetConnectionText());
			
		}else{
			changePage(homepageAlias);
		}

	}
	
	/* ====================================================== */
	
	
	/*
	 * Miscellaneous
	 * 
	 */
	
	function changePage(alias) {
		$.mobile.changePage(domain + '/app/' + alias);
	}
	
	/*
	 * In app browser
	 * 
	 * @param {Event} [e]   Optional event object
	 * @param {String} url  URL to open
	 * @param {String} [target='_system']  Name of target window. Default: '_system'
	 * @param {String} [options='location=yes']  Window open options
	 */
	function openInAppBrowser(e, url, target, options) {
		if (typeof e === 'string') {
			options = target;
			target = url;
			url = e;
		} else {
			e.stopImmediatePropagation();
			e.preventDefault();
		}
		
		/*
		 * Open everything in system browser for Android devices
		 * Android devices cannot open files in InAppBrowser
		 */
		if (window.device && 'ANDROID' === window.device.platform.toUpperCase()) {
			target = '_system';

		}else{
			target = target || '_system';
		}
		
		var options = options || 'location=yes,enableViewportScale=yes';
		window.open(encodeURI(url), target, options);
		return false;
	}

	/* ====================================================== */

	return {
		getLocalStorageItem			: getLocalStorageItem,
		setLocalStorageItem			: setLocalStorageItem,
		
		changePage					: changePage,
		openInAppBrowser			: openInAppBrowser,
		
		checkConnection				: checkConnection,
		
		onDeviceReady				: onDeviceReady,
		
		myOrg						: myOrg,
		
		domain						: domain,
		setDomain					: setDomain,

        // Will prevent update message (templates/update.html):
        version                     : '3.4+'
	}
}(jQuery));

jQuery.ajaxSetup({
	headers: {
		'X-App-Type': 'mobile-native',
		'X-App-Version': (typeof widget === 'object' && widget.version) || -1,
		// Set X-Device to device (stringified) or userAgent or 'Unknown' if both are falsy
		'X-Device': (typeof device === 'object' && JSON && JSON.stringify && JSON.stringify(device)) || (navigator && navigator.userAgent) || 'Unknown'
	}
});

jQuery(document).on('mobileinit', function() {
	$.support.cors						= true;
	$.support.dynamicBaseTag			= true;
	$.mobile.allowCrossDomainPages		= true;
	$.mobile.buttonMarkup.hoverDelay	= 200;
	$.mobile.pushStateEnabled			= false;
	$.mobile.defaultPageTransition		= 'none'; 
	$.mobile.defaultDialogTransition	= 'none';
	$.mobile.phonegapNavigationEnabled	= true;
});

// Open external links in  app browser
jQuery(document).on('click', 'a', function(e) {
	if ($(this).is('[href^="http://"], [href^="https://"], .link-download a')) {
		app.openInAppBrowser(e, this.href, '_blank');
	}
});
$(document.body).addClass('ext-links-adjusted');