/* --- connection.js ----- */

define(['jquery', 'app'], function($, app) {

	var onlineState = true;

	var mod = {
		'setOnlineState':    setOnlineState,
		'getOnlineState':    getOnlineState,
		'onOnline':	         onOnline,
		'onOffline':         onOffline,
		'check':             checkConnection,
		'getType':           getConnectionType,
		'alertDisconnected': alertDisconnected
	};

	/**
	 * setOnlineState
	 * 
	 * Set the online state.
	 * @param	{Boolean}	state	The online state
	 */
	function setOnlineState(state) {
		onlineState = state;
	}

	/**
	 * getOnlineState
	 * 
	 * Get the online state.
	 * @returns	{Boolean}	The online state
	 */
	function getOnlineState() {
		return onlineState;
	}

	/**
	 * onOnline
	 *
	 * Event handler for when gone online. Sets onlineState to true.
	 */
	function onOnline() {
		mod.setOnlineState(true);
	}
	$(document).on('online', mod.onOnline);

	/**
	 * onOffline
	 *
	 * Event handler for when gone offline. Sets onlineState to false.
	 */
	function onOffline() {
		mod.setOnlineState(false);
	}
	$(document).on('offline', mod.onOffline);

	/**
	 * checkConnection
	 * 
	 * Check the connection and set onlineState.
	 * @returns	{Boolean}	Whether connected or not
	 */
	function checkConnection() {
		var isConnected = !!mod.getType();

		mod.setOnlineState(isConnected);
		return isConnected;
	}

	/**
	 * getConnectionType
	 *
	 * Get the connection type.
	 * Should be overwritten in case of PhoneGap. 
	 * @returns	{String}	Connection type
	 */
	function getConnectionType() {
		var trans = app.trans;

		return (trans.connection && trans.connection.unknown) || '?';
	}

	/**
	 * alertDisconnected
	 *
	 * Show alert, telling the user that the device is offline.
	 */
	function alertDisconnected() {
		var trans = app.trans;
		var disconnected = (trans.connection && trans.connection.disconnected) || {};

		$(document).triggerHandler('alert', [disconnected.body, disconnected.title]);
	}

	return mod;
});