/* --- navigation.js ----- */

define(['app'], function(app) {
	
	var domain = app.config.domain;

	var mod = {
		'setDomain':        setDomain,
		'getDomain':        getDomain,
		'getUrlByAlias':    getUrlByAlias,
		'getHomePageAlias': getHomePageAlias,
		'gotoPage':         gotoPage,
		'gotoUrl':          gotoUrl,
		'openUrl':          openUrl
	};

	/**
	 * setDomain
	 * 
	 * Set the app domain
	 * @param   {String} domainStr  The domain to set
	 */
	function setDomain(domainStr) {
		domain = domainStr;
	}

	/**
	 * getDomain
	 * 
	 * Set the app domain
	 * @returns {String}  The app domain
	 */
	function getDomain() {
		return domain;
	}

	/**
	 * getUrlByAlias
	 *
	 * Get URL by page alias (optionally combined with language).
	 * @param   {String} alias   Page alias
	 * @param   {String} [lang]  Page language
	 * @returns {String}         URL of matching page
	 */
	function getUrlByAlias(alias, lang) {
		var language = app.language;

		/* =================
		   TODO: make real
		 ================= */
		if (!lang) {
			lang = language.get();
		}
		return language.isSupported(lang) ? 'URL-' + lang : 'URL';
	}

	/**
	 * getHomePageAlias
	 * 
	 * Get alias of the homepage for the given language.
	 * @param   {String} [lang]  Optional language to get the homepage alias for
	 * @returns {String}         Homepage alias
	 */
	function getHomePageAlias(lang) {
		var homePageAlias = app.config.homePageAlias;

		if (typeof homePageAlias === 'string') {
			return homePageAlias;
		}
		return (lang && app.language.isSupported(lang) && homePageAlias[lang]) || homePageAlias['default'];
	}

	/**
	 * gotoPage
	 * 
	 * Got to page based on alias.
	 * @param   {String} alias  Alias of the page to go to
	 */
	function gotoPage(alias) {
		mod.gotoUrl(mod.getUrlByAlias(alias));
	}

	/**
	 * gotoUrl
	 * 
	 * Go to the given URL.
	 * @param   {String} url  The URL to go to
	 */
	function gotoUrl(url) {
		window.location.href = url;
	}

	/**
	 * openUrl
	 * 
	 * Open given URL in new window.
	 * @param   {String} url            The URL to go to
	 * @param   {String} [target = '']  Name of target window. Default: ''
	 * @param   {String} [features]     Comma separated list of window features
	 * @returns {Object}                Reference to opened window
	 */
	function openUrl(url, target, features) {
		return window.open(url, target || '', features);
	}

	return mod;
});