/* --- notifications.js ----- */

define(['jquery', 'app'], function($, app) {

	var mod = {
		'alert':   alert,
		'confirm': confirm
	};
	
	/**
	 * alert
	 * 
	 * Show alert dialog and call optional callback function when closed.
	 * @param   {String}   body      Body text
	 * @param   {Function} [fn]      Callback function
	 * @param   {String}   title     Title text
	 * @param   {String}   [button]  Button label
	 */
	function alert(body, fn, title, button) {
		if (typeof fn === 'string') {
			title = fn;
			fn = function() {};
		}
		if (navigator.notification && navigator.notification.alert) {
			navigator.notification.alert(body, fn, title, button);
		} else {
			window.alert(body);
			fn();
		}
	}
	$(document).on('alert', mod.alert);

	/**
	 * confirm
	 * 
	 * Show confirm dialog and call callback function when closed.
	 * @param   {String}   body      Body text
	 * @param   {Function} fn        Callback function. Recieves index of button pressed (1, 2 or 3)
	 * @param   {String}   title     Title text
	 * @param   {String}   [button]  Comma separated string with button labels. Default: 'OK,Cancel'
	 */
	function confirm(body, fn, title, buttons) {
		var trans;
		var labels;
		var confirmed;
		var buttonOrder;
		var buttonIndex;

		if (navigator.notification && navigator.notification.confirm) {
			navigator.notification.confirm(body, fn, title, button);
		} else {
			trans = app.language.getTranslation();
			labels = (trans && trans.notifications && trans.notifications.buttons) || {};
			buttonOrder = (buttons || '').split(/\s*,\s*/);
			confirmed = window.confirm(body);
			if (buttonOrder[0] === labels.confirm || buttonOrder[1] === labels.cancel) {
				buttonIndex = 1 + confirmed;
			} else {
				buttonIndex = 1 + !confirmed;
			}
			fn(buttonIndex);
		}
	}
	$(document).on('confirm', mod.confirm);

	return mod;
});